package com.ruoyi.system.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.system.domain.TDeptResourceMap;
import com.ruoyi.system.service.ITDeptResourceMapService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 班级资源映射Controller
 * 
 * @author ruoyi
 * @date 2024-10-23
 */
@RestController
@RequestMapping("/map")
public class TDeptResourceMapController extends BaseController
{
    @Autowired
    private ITDeptResourceMapService tDeptResourceMapService;

    /**
     * 查询班级资源映射列表
     */
    @RequiresPermissions("system:map:list")
    @GetMapping("/list")
    public TableDataInfo list(TDeptResourceMap tDeptResourceMap)
    {
        startPage();
        List<TDeptResourceMap> list = tDeptResourceMapService.selectTDeptResourceMapList(tDeptResourceMap);
        return getDataTable(list);
    }

    /**
     * 导出班级资源映射列表
     */
    @RequiresPermissions("system:map:export")
    @Log(title = "班级资源映射", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TDeptResourceMap tDeptResourceMap)
    {
        List<TDeptResourceMap> list = tDeptResourceMapService.selectTDeptResourceMapList(tDeptResourceMap);
        ExcelUtil<TDeptResourceMap> util = new ExcelUtil<TDeptResourceMap>(TDeptResourceMap.class);
        util.exportExcel(response, list, "班级资源映射数据");
    }

    /**
     * 获取班级资源映射详细信息
     */
    @RequiresPermissions("system:map:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(tDeptResourceMapService.selectTDeptResourceMapById(id));
    }

    /**
     * 新增班级资源映射
     */
    @RequiresPermissions("system:map:add")
    @Log(title = "班级资源映射", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TDeptResourceMap tDeptResourceMap)
    {
        return toAjax(tDeptResourceMapService.insertTDeptResourceMap(tDeptResourceMap));
    }

    @RequiresPermissions("system:map:add")
    @Log(title = "班级资源映射", businessType = BusinessType.INSERT)
    @PostMapping("addByResourceIds")
    public AjaxResult addByResourceIds(@RequestBody TDeptResourceMap tDeptResourceMap)
    {
        return toAjax(tDeptResourceMapService.insertTDeptResourceMapByResourceIds(tDeptResourceMap));
    }



    /**
     * 修改班级资源映射
     */
    @RequiresPermissions("system:map:edit")
    @Log(title = "班级资源映射", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TDeptResourceMap tDeptResourceMap)
    {
        return toAjax(tDeptResourceMapService.updateTDeptResourceMap(tDeptResourceMap));
    }

    /**
     * 删除班级资源映射
     */
    @RequiresPermissions("system:map:remove")
    @Log(title = "班级资源映射", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(tDeptResourceMapService.deleteTDeptResourceMapByIds(ids));
    }
}
