package com.ruoyi.system.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.system.domain.TLession;
import com.ruoyi.system.service.ITLessionService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 可成信息Controller
 * 
 * @author ruoyi
 * @date 2024-02-06
 */
@RestController
@RequestMapping("/lession")
public class TLessionController extends BaseController
{
    @Autowired
    private ITLessionService tLessionService;

    /**
     * 查询可成信息列表
     */
    @RequiresPermissions("system:lession:list")
    @GetMapping("/list")
    public TableDataInfo list(TLession tLession)
    {
        startPage();
        List<TLession> list = tLessionService.selectTLessionList(tLession);
        return getDataTable(list);
    }

    /**
     * 导出可成信息列表
     */
    @RequiresPermissions("system:lession:export")
    @Log(title = "可成信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TLession tLession)
    {
        List<TLession> list = tLessionService.selectTLessionList(tLession);
        ExcelUtil<TLession> util = new ExcelUtil<TLession>(TLession.class);
        util.exportExcel(response, list, "可成信息数据");
    }

    /**
     * 获取可成信息详细信息
     */
    @RequiresPermissions("system:lession:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(tLessionService.selectTLessionById(id));
    }

    /**
     * 新增可成信息
     */
    @RequiresPermissions("system:lession:add")
    @Log(title = "可成信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TLession tLession)
    {
        return toAjax(tLessionService.insertTLession(tLession));
    }

    /**
     * 修改可成信息
     */
    @RequiresPermissions("system:lession:edit")
    @Log(title = "可成信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TLession tLession)
    {
        return toAjax(tLessionService.updateTLession(tLession));
    }

    /**
     * 删除可成信息
     */
    @RequiresPermissions("system:lession:remove")
    @Log(title = "可成信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(tLessionService.deleteTLessionByIds(ids));
    }
}
