package com.ruoyi.system.controller;

import java.util.List;
import java.io.IOException;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.system.api.domain.SysDictData;
import com.ruoyi.system.service.ISysDictDataService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.system.domain.TResource;
import com.ruoyi.system.service.ITResourceService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 资源Controller
 * 
 * @author ruoyi
 * @date 2024-10-22
 */
@RestController
@RequestMapping("/resource")
public class TResourceController extends BaseController
{
    @Autowired
    private ITResourceService tResourceService;

    @Resource
    private ISysDictDataService iSysDictDataService;

    /**
     * 查询资源列表
     */
    @RequiresPermissions("system:resource:list")
    @GetMapping("/list")
    public TableDataInfo list(TResource tResource)
    {
        startPage();
        List<TResource> list = tResourceService.selectTResourceList(tResource);
        return getDataTable(list);
    }

    /**
     * 导出资源列表
     */
    @RequiresPermissions("system:resource:export")
    @Log(title = "资源", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TResource tResource)
    {
        List<TResource> list = tResourceService.selectTResourceList(tResource);
        ExcelUtil<TResource> util = new ExcelUtil<TResource>(TResource.class);
        util.exportExcel(response, list, "资源数据");
    }

    /**
     * 获取资源详细信息
     */
    @RequiresPermissions("system:resource:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(tResourceService.selectTResourceById(id));
    }

    /**
     * 新增资源
     */
    @RequiresPermissions("system:resource:add")
    @Log(title = "资源", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TResource tResource)
    {

        SysDictData sysDictData = new SysDictData();
        sysDictData.setDictValue(tResource.getResourceType());
        List<SysDictData> dict = iSysDictDataService.selectDictDataList(sysDictData);
        tResource.setResourceTypeName(dict.get(0).getDictLabel());

        return toAjax(tResourceService.insertTResource(tResource));
    }

    /**
     * 修改资源
     */
    @RequiresPermissions("system:resource:edit")
    @Log(title = "资源", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TResource tResource)
    {
        return toAjax(tResourceService.updateTResource(tResource));
    }

    /**
     * 删除资源
     */
    @RequiresPermissions("system:resource:remove")
    @Log(title = "资源", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(tResourceService.deleteTResourceByIds(ids));
    }
}
