package com.ruoyi.system.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.system.domain.TSignin;
import com.ruoyi.system.service.ITSigninService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 签到Controller
 * 
 * @author ruoyi
 * @date 2024-02-06
 */
@RestController
@RequestMapping("/signin")
public class TSigninController extends BaseController
{
    @Autowired
    private ITSigninService tSigninService;

    /**
     * 查询签到列表
     */
    @RequiresPermissions("system:signin:list")
    @GetMapping("/list")
    public TableDataInfo list(TSignin tSignin)
    {
        startPage();
        List<TSignin> list = tSigninService.selectTSigninList(tSignin);
        return getDataTable(list);
    }

    /**
     * 导出签到列表
     */
    @RequiresPermissions("system:signin:export")
    @Log(title = "签到", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TSignin tSignin)
    {
        List<TSignin> list = tSigninService.selectTSigninList(tSignin);
        ExcelUtil<TSignin> util = new ExcelUtil<TSignin>(TSignin.class);
        util.exportExcel(response, list, "签到数据");
    }

    /**
     * 获取签到详细信息
     */
    @RequiresPermissions("system:signin:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(tSigninService.selectTSigninById(id));
    }

    /**
     * 新增签到
     */
    @RequiresPermissions("system:signin:add")
    @Log(title = "签到", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TSignin tSignin)
    {
        return toAjax(tSigninService.insertTSignin(tSignin));
    }

    /**
     * 修改签到
     */
    @RequiresPermissions("system:signin:edit")
    @Log(title = "签到", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TSignin tSignin)
    {
        return toAjax(tSigninService.updateTSignin(tSignin));
    }

    /**
     * 删除签到
     */
    @RequiresPermissions("system:signin:remove")
    @Log(title = "签到", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(tSigninService.deleteTSigninByIds(ids));
    }
}
