package com.ruoyi.system.service.impl;

import java.util.List;

import com.ruoyi.common.core.utils.uuid.UUID;
import com.ruoyi.system.domain.TResource;
import com.ruoyi.system.mapper.TResourceMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.TDeptResourceMapMapper;
import com.ruoyi.system.domain.TDeptResourceMap;
import com.ruoyi.system.service.ITDeptResourceMapService;

import javax.annotation.Resource;

/**
 * 班级资源映射Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-10-23
 */
@Service
public class TDeptResourceMapServiceImpl implements ITDeptResourceMapService 
{

    @Autowired
    private TDeptResourceMapMapper tDeptResourceMapMapper;
    @Resource
    private TResourceMapper resourceMapper;

    /**
     * 查询班级资源映射
     * 
     * @param id 班级资源映射主键
     * @return 班级资源映射
     */
    @Override
    public TDeptResourceMap selectTDeptResourceMapById(String id)
    {
        return tDeptResourceMapMapper.selectTDeptResourceMapById(id);
    }

    /**
     * 查询班级资源映射列表
     * 
     * @param tDeptResourceMap 班级资源映射
     * @return 班级资源映射
     */
    @Override
    public List<TDeptResourceMap> selectTDeptResourceMapList(TDeptResourceMap tDeptResourceMap)
    {
        return tDeptResourceMapMapper.selectTDeptResourceMapList(tDeptResourceMap);
    }

    /**
     * 新增班级资源映射
     * 
     * @param tDeptResourceMap 班级资源映射
     * @return 结果
     */
    @Override
    public int insertTDeptResourceMap(TDeptResourceMap tDeptResourceMap)
    {
        return tDeptResourceMapMapper.insertTDeptResourceMap(tDeptResourceMap);
    }

    @Override
    public int insertTDeptResourceMapByResourceIds(TDeptResourceMap tDeptResourceMap) {


        for(String resid : tDeptResourceMap.getResourceSelection()){
            TResource resource = resourceMapper.selectTResourceById(resid);

            TDeptResourceMap map = new TDeptResourceMap();
            map.setId( UUID.fastUUID().toString());
            map.setDeptId(tDeptResourceMap.getDeptId());
            map.setResourceId(resid);
            map.setResourceName(resource.getResourceName());
            map.setSeq(0L);
            map.setResourceType(resource.getResourceType());
            map.setResourceTypeName(resource.getResourceTypeName());
            map.setResourceUrl(resource.getUrl());
            tDeptResourceMapMapper.insertTDeptResourceMap(map);

        }
        return 1;
    }

    /**
     * 修改班级资源映射
     * 
     * @param tDeptResourceMap 班级资源映射
     * @return 结果
     */
    @Override
    public int updateTDeptResourceMap(TDeptResourceMap tDeptResourceMap)
    {
        return tDeptResourceMapMapper.updateTDeptResourceMap(tDeptResourceMap);
    }

    /**
     * 批量删除班级资源映射
     * 
     * @param ids 需要删除的班级资源映射主键
     * @return 结果
     */
    @Override
    public int deleteTDeptResourceMapByIds(String[] ids)
    {
        return tDeptResourceMapMapper.deleteTDeptResourceMapByIds(ids);
    }

    /**
     * 删除班级资源映射信息
     * 
     * @param id 班级资源映射主键
     * @return 结果
     */
    @Override
    public int deleteTDeptResourceMapById(String id)
    {
        return tDeptResourceMapMapper.deleteTDeptResourceMapById(id);
    }
}
